abacusai.prediction_metric — AbacusAI documentation

# `abacusai.prediction_metric`

## Module Contents

### Classes

`PredictionMetric` | A Prediction Metric job description.

class abacusai.prediction_metric.PredictionMetric(client, createdAt=None, featureGroupId=None, predictionMetricConfig=None, predictionMetricId=None, modelMonitorId=None, projectId=None, refreshSchedules={}, latestPredictionMetricVersionDescription={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A Prediction Metric job description.

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - createdAt (str) – Date and time when this prediction metric was created.

    - featureGroupId (str) – The feature group used as input to this prediction metric.

    - predictionMetricConfig (json) – Specification for the prediction metric to run in this job.

    - predictionMetricId (str) – The unique identifier of the prediction metric.

    - modelMonitorId (str) – unique string identifer for model monitor that created prediction metric

    - projectId (str) – The project this prediction metric belongs to.

    - latestPredictionMetricVersionDescription (PredictionMetricVersion) – Description of the latest prediction metric version (if any).

    - refreshSchedules (RefreshSchedule) – List of schedules that determines when the next version of the dataset will be created.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns

      The current object

    Return type

      PredictionMetric

  describe(should_include_latest_version_description=True)

    Describe a Prediction Metric.

    Parameters

      should_include_latest_version_description (bool) – include the description of the latest prediction metric version

    Returns

      The prediction metric object.

    Return type

      PredictionMetric

  delete()

    Removes an existing PredictionMetric.

    Parameters

      prediction_metric_id (str) – The unique ID associated with the prediction metric.

  run()

    Creates a new prediction metrics job run for the given prediction metric job description, and starts that job.

    Configures and starts the computations running to compute the prediciton metric.

    Parameters

      prediction_metric_id (str) – The prediction metric job description to apply for configuring a prediction metric job.

    Returns

      A prediction metric version. For more information, please refer to the details on the object (below).

    Return type

      PredictionMetricVersion

  list_versions(limit=100, start_after_id=None)

    List the prediction metric versions for a prediction metric.

    Parameters

      - limit (int) – The the number of prediction metric instances to be retrieved.

      - start_after_id (str) – An offset parameter to exclude all prediction metric versions till the specified prediction metric ID.

    Returns

      The prediction metric instances for this prediction metric.

    Return type

      PredictionMetricVersion